@@ -10,26 +10,30 @@ use Data::Validate::Type;
 
 =head1 NAME
 
-Business::SiteCatalyst::Report - Interface to Adobe Omniture SiteCatalyst's REST Report API.
+Business::SiteCatalyst::Report - Interface to Adobe Omniture SiteCatalyst's REST API 'Report' module.
 
 
 =head1 VERSION
 
-Version 1.0.1
+Version 1.2.0
 
 =cut
 
-our $VERSION = '1.0.1';
+our $VERSION = '1.2.0';
 
 
 =head1 SYNOPSIS
 
-This module allows you to interact with Adobe Omniture SiteCatalyst, an analytics Service
-Provider. It encapsulates all the communications with the API provided by Adobe
-SiteCatalyst to offer a Perl interface for managing reports.
+This module allows you to interact with Adobe (formerly Omniture) SiteCatalyst,
+a web analytics service. It encapsulates all the communications with the API 
+provided by Adobe SiteCatalyst to offer a Perl interface for managing reports,
+pulling company-specific SiteCatalyst data (ex: token usage), uploading SAINT 
+data (feature not implemented yet), etc.
 
-Please note that you will need to have purchased the Adobe SiteCatalyst product, and have web services enabled
-first in order to obtain a web services shared secret, as well as agree with the Terms and Conditions for using the API.
+Please note that you will need to have purchased the Adobe SiteCatalyst product,
+and have web services enabled within your account first in order to obtain a web
+services shared secret, as well as agree with the Terms and Conditions for using 
+the API.
 
 	use Business::SiteCatalyst;
 	
@@ -66,7 +70,7 @@ first in order to obtain a web services shared secret, as well as agree with the
 	
 	unless ( defined $results )
 	{
-		$report->cancel();
+		$cancel_success = $report->cancel();
 	}
 
 =head1 METHODS
@@ -151,6 +155,7 @@ Queue a Business::SiteCatalyst report.
 
 	$report->queue( %report_arguments );
 
+	# Example: Top 5 referrers report
 	$report->queue(
 		dateFrom      => "2012-04-01",
 		dateTo        => "2012-04-15",
@@ -178,7 +183,7 @@ sub queue
 		}
 	);
 	
-	# Store report id, we'll need it to check the status
+	# Store report id; we'll need it to check the status
 	$self->{'id'} = $response->{'reportID'};
 	
 	return $response;
@@ -264,9 +269,10 @@ sub retrieve
 
 =head2 cancel()
 
-Cancel queued report request.
+Cancel previously submitted report request, and removes it from processing queue.
+Returns 1 if successful, otherwise 0.
 
-	$report->cancel();
+	my $cancel_success = $report->cancel();
 
 =cut
 
@@ -274,6 +280,24 @@ sub cancel
 {
 	my ( $self, %args ) = @_;
 	
+	my $site_catalyst = $self->get_site_catalyst();
+	my $verbose = $site_catalyst->verbose();
+	
+	my $response = $site_catalyst->send_request(
+		method => 'Report.CancelReport',
+		data   =>
+		{
+			reportID => $self->get_id(),
+		}
+	);
+	
+	if ( !defined($response) )
+	{
+		croak "Fatal error. No response.";
+	}
+
+	return $response;
+
 }
 
 
@@ -355,6 +379,7 @@ L<http://search.cpan.org/dist/Business-SiteCatalyst/>
 
 Thanks to ThinkGeek (L<http://www.thinkgeek.com/>) and its corporate overlords
 at Geeknet (L<http://www.geek.net/>), for footing the bill while I write code for them!
+Special thanks for technical help from fellow ThinkGeek CPAN author Guillaume Aubert L<http://search.cpan.org/~aubertg/>
 
 
 =head1 COPYRIGHT & LICENSE
